.. arkouda documentation master file, created by
   sphinx-quickstart on Tue Oct  1 08:16:22 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to arkouda's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
      
   setup/prerequisites
   setup/installation
   setup/testing
   setup/quickstart

   usage
   examples
   contributing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
